@@ -38,7 +38,7 @@ VolumeObject::~VolumeObject()
 
 qint64 VolumeObject::volume() const
 {
-    return m_volume.values[0];
+    return pa_cvolume_avg(&m_volume);
 }
 
 bool VolumeObject::isMuted() const
@@ -66,9 +66,9 @@ QStringList VolumeObject::channels() const
     return m_channels;
 }
 
-QList<qint64> VolumeObject::channelVolumes() const
+QList<qreal> VolumeObject::channelVolumes() const
 {
-    QList<qint64> ret;
+    QList<qreal> ret;
     ret.reserve(m_volume.channels);
     for (int i = 0; i < m_volume.channels; ++i) {
         ret << m_volume.values[i];
